==> vst3sdk-docs-3.7.14_build_55-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/vstsdk/search/functions_4.js <==
var searchData=
[
  ['data_0',['data',['../structVST3_1_1UID.html#a5104a0bb736979b3a278e9c8214e941e',1,'VST3::UID']]],
  ['dataexchangehandler_1',['DataExchangeHandler',['../classSteinberg_1_1Vst_1_1DataExchangeHandler.html#aea634a2e1293658a1e343bbc8bf71dd7',1,'Steinberg::Vst::DataExchangeHandler::DataExchangeHandler(IAudioProcessor *processor, ConfigCallback &amp;&amp;callback)'],['../classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a82c9767f227ed858413efa54450309ea',1,'Steinberg::Vst::DataExchangeHandler::DataExchangeHandler(IAudioProcessor *processor, const ConfigCallback &amp;callback)']]],
  ['dataexchangereceiverhandler_2',['DataExchangeReceiverHandler',['../classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html#a04f7bfae5ffb6c3841cad64acfed4747',1,'Steinberg::Vst::DataExchangeReceiverHandler']]],
  ['decodescalefactor_3',['decodeScaleFactor',['../structVST3_1_1Hosting_1_1Module_1_1Snapshot.html#af83d1c09a84057dd3974be7ef641e89f',1,'VST3::Hosting::Module::Snapshot']]],
  ['decodeuid_4',['decodeUID',['../structVST3_1_1Hosting_1_1Module_1_1Snapshot.html#a4844a6fefcbb5a468506e95447cb3500',1,'VST3::Hosting::Module::Snapshot']]],
  ['def_5fclass_5fiid_5',['DEF_CLASS_IID',['../../base/namespaceSteinberg.html#a0a5776df696f816f7fcc81666e242d81',1,'Steinberg']]],
  ['deferupdates_6',['deferUpdates',['../../base/classSteinberg_1_1IUpdateHandler.html#a161a23aead9a302f8b4b2021d8553e29',1,'Steinberg::IUpdateHandler']]],
  ['delay_7',['Delay',['../structSteinberg_1_1Vst_1_1BypassProcessor_1_1Delay.html#a59bfd0438cb1c6514a34373f69437691',1,'Steinberg::Vst::BypassProcessor::Delay']]],
  ['denormalizealpha_8',['DenormalizeAlpha',['../../base/namespaceSteinberg.html#abfe74133ed684fa31c7227a9d1a4b3ce',1,'Steinberg']]],
  ['denormalizecolorcomponent_9',['DenormalizeColorComponent',['../../base/namespaceSteinberg.html#abad8045987a3d33b9421e724c06a9d6f',1,'Steinberg']]],
  ['destroy_10',['destroy',['../../base/structSteinberg_1_1FUnknownImpl_1_1Destroyer.html#a7dae24d8343a7da23399a3da74681a39',1,'Steinberg::FUnknownImpl::Destroyer']]],
  ['destroybuffers_11',['destroyBuffers',['../classSteinberg_1_1Vst_1_1HostProcessData.html#ac9368c70233f027934c6414975720e68',1,'Steinberg::Vst::HostProcessData']]],
  ['detachdata_12',['detachData',['../classSteinberg_1_1MemoryStream.html#a63b0ce2964c436aa0cbcbeaf18254583',1,'Steinberg::MemoryStream']]],
  ['disableerrorui_13',['disableErrorUI',['../../base/classSteinberg_1_1IErrorContext.html#a6984fa8a3247acec65a270803e43bc84',1,'Steinberg::IErrorContext']]],
  ['discardcurrentblock_14',['discardCurrentBlock',['../classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a49505377ab844ba48d3b85fd224f7d63',1,'Steinberg::Vst::DataExchangeHandler']]],
  ['disconnect_15',['disconnect',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IConnectionPoint.html#ad85bd437968bec6e403fb3cba699b01e',1,'Steinberg::Vst::IConnectionPoint::disconnect()'],['../classSteinberg_1_1Vst_1_1ComponentBase.html#adbcbdfd9061c4f951db444f60d358b12',1,'Steinberg::Vst::ComponentBase::disconnect()'],['../classSteinberg_1_1Vst_1_1ConnectionProxy.html#a6c2e8e8b1fbabb82ea67dcf81fb0c6b6',1,'Steinberg::Vst::ConnectionProxy::disconnect(IConnectionPoint *other) override'],['../classSteinberg_1_1Vst_1_1ConnectionProxy.html#a12db172f74059f7eceb63714f4589aa0',1,'Steinberg::Vst::ConnectionProxy::disconnect()']]],
  ['disconnectcomponents_16',['disconnectComponents',['../classSteinberg_1_1Vst_1_1PlugProvider.html#a12cbed77ca2d669e478a375473de6fb1',1,'Steinberg::Vst::PlugProvider']]]
];

==> vst3sdk-docs-3.8.0_build_66-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/vstsdk/search/functions_4.js <==
var searchData=
[
  ['data_0',['data',['../structVST3_1_1UID.html#a5104a0bb736979b3a278e9c8214e941e',1,'VST3::UID']]],
  ['dataexchangehandler_1',['DataExchangeHandler',['../classSteinberg_1_1Vst_1_1DataExchangeHandler.html#aea634a2e1293658a1e343bbc8bf71dd7',1,'Steinberg::Vst::DataExchangeHandler::DataExchangeHandler(IAudioProcessor *processor, ConfigCallback &amp;&amp;callback)'],['../classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a82c9767f227ed858413efa54450309ea',1,'Steinberg::Vst::DataExchangeHandler::DataExchangeHandler(IAudioProcessor *processor, const ConfigCallback &amp;callback)']]],
  ['dataexchangereceiverhandler_2',['DataExchangeReceiverHandler',['../classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html#a04f7bfae5ffb6c3841cad64acfed4747',1,'Steinberg::Vst::DataExchangeReceiverHandler']]],
  ['decodescalefactor_3',['decodeScaleFactor',['../structVST3_1_1Hosting_1_1Module_1_1Snapshot.html#af83d1c09a84057dd3974be7ef641e89f',1,'VST3::Hosting::Module::Snapshot']]],
  ['decodeuid_4',['decodeUID',['../structVST3_1_1Hosting_1_1Module_1_1Snapshot.html#a4844a6fefcbb5a468506e95447cb3500',1,'VST3::Hosting::Module::Snapshot']]],
  ['def_5fclass_5fiid_5',['DEF_CLASS_IID',['../namespaceSteinberg.html#a0a5776df696f816f7fcc81666e242d81',1,'Steinberg']]],
  ['deferupdates_6',['deferUpdates',['../../base/classSteinberg_1_1IUpdateHandler.html#a161a23aead9a302f8b4b2021d8553e29',1,'Steinberg::IUpdateHandler']]],
  ['delay_7',['Delay',['../structSteinberg_1_1Vst_1_1BypassProcessor_1_1Delay.html#a59bfd0438cb1c6514a34373f69437691',1,'Steinberg::Vst::BypassProcessor::Delay']]],
  ['denormalizealpha_8',['DenormalizeAlpha',['../../base/namespaceSteinberg.html#abfe74133ed684fa31c7227a9d1a4b3ce',1,'Steinberg']]],
  ['denormalizecolorcomponent_9',['DenormalizeColorComponent',['../../base/namespaceSteinberg.html#abad8045987a3d33b9421e724c06a9d6f',1,'Steinberg']]],
  ['destroy_10',['destroy',['../../base/structSteinberg_1_1FUnknownImpl_1_1Destroyer.html#a7dae24d8343a7da23399a3da74681a39',1,'Steinberg::FUnknownImpl::Destroyer']]],
  ['destroybuffers_11',['destroyBuffers',['../classSteinberg_1_1Vst_1_1HostProcessData.html#ac9368c70233f027934c6414975720e68',1,'Steinberg::Vst::HostProcessData']]],
  ['detachdata_12',['detachData',['../classSteinberg_1_1MemoryStream.html#a63b0ce2964c436aa0cbcbeaf18254583',1,'Steinberg::MemoryStream']]],
  ['disableerrorui_13',['disableErrorUI',['../../base/classSteinberg_1_1IErrorContext.html#a6984fa8a3247acec65a270803e43bc84',1,'Steinberg::IErrorContext']]],
  ['discardcurrentblock_14',['discardCurrentBlock',['../classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a49505377ab844ba48d3b85fd224f7d63',1,'Steinberg::Vst::DataExchangeHandler']]],
  ['disconnect_15',['disconnect',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IConnectionPoint.html#ad85bd437968bec6e403fb3cba699b01e',1,'Steinberg::Vst::IConnectionPoint::disconnect()'],['../classSteinberg_1_1Vst_1_1ComponentBase.html#adbcbdfd9061c4f951db444f60d358b12',1,'Steinberg::Vst::ComponentBase::disconnect()'],['../classSteinberg_1_1Vst_1_1ConnectionProxy.html#a6c2e8e8b1fbabb82ea67dcf81fb0c6b6',1,'Steinberg::Vst::ConnectionProxy::disconnect(IConnectionPoint *other) override'],['../classSteinberg_1_1Vst_1_1ConnectionProxy.html#a12db172f74059f7eceb63714f4589aa0',1,'Steinberg::Vst::ConnectionProxy::disconnect()']]],
  ['disconnectcomponents_16',['disconnectComponents',['../classSteinberg_1_1Vst_1_1PlugProvider.html#a12cbed77ca2d669e478a375473de6fb1',1,'Steinberg::Vst::PlugProvider']]]
];
